@@ -5,14 +5,13 @@ use utf8;
 
 package Dist::Zilla::Util::RoleDB::Entry::Phase;
 
-our $VERSION = '0.002001';
+our $VERSION = '0.003000';
 
 # ABSTRACT: Extracted meta-data about a role that represents a phase
 
 our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
 
 use Moose qw( has extends );
-use MooseX::AttributeShortcuts;
 
 extends 'Dist::Zilla::Util::RoleDB::Entry';
 
@@ -55,7 +54,7 @@ Dist::Zilla::Util::RoleDB::Entry::Phase - Extracted meta-data about a role that
 
 =head1 VERSION
 
-version 0.002001
+version 0.003000
 
 =head1 METHODS
 
@@ -71,11 +70,11 @@ Returns the method C<Dist::Zilla> calls to implement this phase
 
 =head1 AUTHOR
 
-Kent Fredric <kentfredric@gmail.com>
+Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Kent Fredric <kentfredric@gmail.com>.
+This software is copyright (c) 2015 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
